import { SDJwt } from './sdjwt';
import { DisclosureFrame, SDJWTCompact, SDJWTConfig, kbPayload } from './type';
import { KeyLike } from 'jose';
export * from './type';
export * from './sdjwt';
export * from './kbjwt';
export * from './crypto';
export * from './jwt';
export * from './base64url';
export * from './decoy';
export * from './disclosure';
export declare const defaultConfig: Required<SDJWTConfig>;
export declare class SDJwtInstance {
    static DEFAULT_ALG: string;
    static DEFAULT_HASH_ALG: string;
    private userConfig;
    constructor(userConfig?: SDJWTConfig);
    create(userConfig?: SDJWTConfig): SDJwtInstance;
    private createKBJwt;
    issue<Payload extends object>(payload: Payload, privateKey: Uint8Array | KeyLike, disclosureFrame?: DisclosureFrame<Payload>, options?: {
        header?: object;
        sign_alg?: string;
        hash_alg?: string;
        kb?: {
            alg: string;
            payload: kbPayload;
            privateKey: Uint8Array | KeyLike;
        };
    }): Promise<SDJWTCompact>;
    present(encodedSDJwt: string, presentationKeys?: string[]): Promise<SDJWTCompact>;
    verify(encodedSDJwt: string, publicKey: Uint8Array | KeyLike, requiredClaimKeys?: string[], options?: {
        kb?: {
            publicKey: Uint8Array | KeyLike;
        };
    }): Promise<boolean>;
    validate(encodedSDJwt: string, publicKey: Uint8Array | KeyLike): Promise<boolean>;
    config(newConfig: SDJWTConfig): void;
    encode(sdJwt: SDJwt): SDJWTCompact;
    decode(endcodedSDJwt: SDJWTCompact): SDJwt<Record<string, any>, Record<string, any>, import("./type").kbHeader, kbPayload>;
    keys(endcodedSDJwt: SDJWTCompact): Promise<string[]>;
    presentableKeys(endcodedSDJwt: SDJWTCompact): Promise<string[]>;
    getClaims(endcodedSDJwt: SDJWTCompact): Promise<unknown>;
    getKeyBinding(endcodedSDJwt: SDJWTCompact): kbPayload | undefined;
}
declare const defaultInstance: SDJwtInstance;
export default defaultInstance;
